@@ -4,16 +4,16 @@
 # Copyright 2010 Joanmarie Diggs
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -27,11 +27,10 @@ __copyright__ = "Copyright (c) 2009-2010 Sun Microsystems Inc."  \
                 "Copyright (c) 2010 Joanmarie Diggs"
 __license__   = "LGPL"
 
-import gtk
+from gi.repository import Gtk
 import pyatspi
 
-import orca.default as default
-import orca.input_event as input_event
+import orca.scripts.default as default
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.settings as settings
@@ -99,13 +98,11 @@ class Script(default.Script):
         return Utilities(self)
 
     def getAppPreferencesGUI(self):
-        """Return a GtkVBox contain the application unique configuration
-        GUI items for the current application.
-        """
+        """Return a GtkGrid containing the application unique configuration
+        GUI items for the current application."""
 
-        vbox = gtk.VBox(False, 0)
-        vbox.set_border_width(12)
-        gtk.Widget.show(vbox)
+        grid = Gtk.Grid()
+        grid.set_border_width(12)
 
         # Translators: The Package Manager application notifies the
         # user of minor errors by displaying an icon in the status
@@ -115,15 +112,15 @@ class Script(default.Script):
         # the notification icon has appeared.
         #
         label = _("Notify me when errors have been logged.")
-        self.presentLoggedErrorsCheckButton = gtk.CheckButton(label)
-        gtk.Widget.show(self.presentLoggedErrorsCheckButton)
-        gtk.Box.pack_start(vbox, self.presentLoggedErrorsCheckButton,
-                           False, False, 0)
-        gtk.ToggleButton.set_active(
-            self.presentLoggedErrorsCheckButton,
-            script_settings.presentLoggedErrors)
+        value = script_settings.presentLoggedErrors
+        self.presentLoggedErrorsCheckButton = \
+            Gtk.CheckButton.new_with_mnemonic(label)
+        self.presentLoggedErrorsCheckButton.set_active(value)
+        grid.attach(self.presentLoggedErrorsCheckButton, 0, 0, 1, 1)
 
-        return vbox
+        grid.show_all()
+
+        return grid
 
     def setAppPreferences(self, prefs):
         """Write out the application specific preferences lines and set the
@@ -151,10 +148,8 @@ class Script(default.Script):
 
         # Prevent chattiness when arrowing out of or into a link.
         #
-        if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent) \
-           and orca_state.lastNonModifierKeyEvent \
-           and orca_state.lastNonModifierKeyEvent.event_string in \
-               ["Left", "Right", "Up", "Down"] \
+        lastKey, mods = self.utilities.lastKeyAndModifiers()
+        if lastKey in ["Left", "Right", "Up", "Down"] \
            and event and event.type.startswith("focus:") \
            and (self.utilities.isLink(oldLocusOfFocus) \
            or self.utilities.isLink(newLocusOfFocus)):
@@ -434,10 +429,8 @@ class Script(default.Script):
         except:
             return
 
-        if text.caretOffset == text.characterCount \
-           and isinstance(orca_state.lastInputEvent,
-                          input_event.KeyboardEvent) \
-           and orca_state.lastNonModifierKeyEvent.event_string == "Right":
+        lastKey, mods = self.utilities.lastKeyAndModifiers()
+        if text.caretOffset == text.characterCount and lastKey == "Right":
             nextObj = self.getRelationTarget(obj, pyatspi.RELATION_FLOWS_TO)
             if nextObj and nextObj.getRole() == pyatspi.ROLE_TEXT:
                 obj = nextObj
