@@ -25,7 +25,6 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2010 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import gtk
 import pyatspi
 
 import orca.orca as orca
@@ -68,20 +67,19 @@ class Script(Gecko.Script):
         return Utilities(self)
 
     def getAppPreferencesGUI(self):
-        """Return a GtkVBox contain the application unique configuration
-        GUI items for the current application.
-        """
+        """Return a GtkGrid containing the application unique configuration
+        GUI items for the current application."""
 
-        vbox = Gecko.Script.getAppPreferencesGUI(self)
+        grid = Gecko.Script.getAppPreferencesGUI(self)
 
         # We need to maintain a separate setting for grabFocusOnAncestor
         # because the version of Gecko used by Yelp might be different
         # from that used by Firefox. See bug 608149.
         #
-        gtk.ToggleButton.set_active(self.grabFocusOnAncestorCheckButton,
-                                    script_settings.grabFocusOnAncestor)
+        self.grabFocusOnAncestorCheckButton.set_active(
+            script_settings.grabFocusOnAncestor)
 
-        return vbox
+        return grid
 
     def setAppPreferences(self, prefs):
         """Write out the application specific preferences lines and set the
