@@ -3,21 +3,20 @@
 # Copyright 2005-2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
 
-
 """Custom script for Gecko toolkit.
 Please refer to the following URL for more information on the AT-SPI
 implementation in Gecko:
@@ -33,7 +32,6 @@ __license__   = "LGPL"
 import pyatspi
 
 import orca.braille_generator as braille_generator
-import orca.orca_state as orca_state
 
 from orca.orca_i18n import _ # for gettext support
 
@@ -222,18 +220,17 @@ class BrailleGenerator(braille_generator.BrailleGenerator):
     def _generateFocusedItem(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
-        if role == pyatspi.ROLE_LIST:
-            item = None
-            selection = obj.querySelection()
-            for i in xrange(obj.childCount):
-                if selection.isChildSelected(i):
-                    item = obj[i]
-                    break
-            item = item or obj[0]
-            if item and (item != orca_state.locusOfFocus):
-                name = self._generateName(item, **args)
-                if name and name != self._generateLabel(obj, **args):
-                    result.extend(name)
+        if role != pyatspi.ROLE_LIST:
+            return result
+
+        s = obj.querySelection()
+        items = [s.getSelectedChild(i) for i in xrange(s.nSelectedChildren)]
+        if not items:
+            items.append(obj[0])
+        items = map(self._generateName, items)
+        for item in items:
+            result.extend(item)
+
         return result
 
     def generateBraille(self, obj, **args):
